summaryrefslogtreecommitdiff
path: root/src/prop/sat.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/prop/sat.h')
-rw-r--r--src/prop/sat.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/prop/sat.h b/src/prop/sat.h
index 13b32f18d..be3ed244b 100644
--- a/src/prop/sat.h
+++ b/src/prop/sat.h
@@ -108,8 +108,8 @@ public:
virtual void addClause(SatClause& clause, bool removable) = 0;
/** Create a new boolean variable in the solver. */
virtual SatVariable newVar(bool theoryAtom = false) = 0;
- /** Get the current decision level of the solver */
- virtual int getLevel() const = 0;
+ /** Get the current user assertion level of the solver */
+ virtual int getAssertionLevel() const = 0;
/** Unregister the variable (of the literal) from solving */
virtual void unregisterVar(SatLiteral lit) = 0;
/** Register the variable (of the literal) for solving */
@@ -240,7 +240,7 @@ public:
/** Call modelValue() when the search is done.*/
SatLiteralValue modelValue(SatLiteral l);
- int getLevel() const;
+ int getAssertionLevel() const;
void push();
@@ -341,7 +341,7 @@ inline void SatSolver::pop() {
d_minisat->pop();
}
-inline int SatSolver::getLevel() const {
+inline int SatSolver::getAssertionLevel() const {
return d_minisat->getAssertionLevel();
}
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback